@@ -1,10 +1,12 @@
-from pyboleto.data import BoletoData
 import os.path
 
-class BoletoReal( BoletoData ):
+from pyboleto.data import BoletoData
+
+
+class BoletoReal(BoletoData):
 
     def __init__(self, *args, **kwargs):
-        super(BoletoReal , self).__init__(*args, **kwargs)
+        super(BoletoReal, self).__init__(*args, **kwargs)
 
         self.codigo_banco = "356"
         self.logo_image_path = os.path.dirname(__file__) + \
@@ -19,15 +21,15 @@ class BoletoReal( BoletoData ):
     @property
     def digitao_cobranca(self):
         num = "%s%s%s" % (
-            self.nosso_numero, 
-            self.agencia_cedente, 
+            self.nosso_numero,
+            self.agencia_cedente,
             self.conta_cedente
         )
         dv = self.modulo10(num)
         return dv
 
     def calculate_dv_barcode(self, line):
-        dv = self.modulo11(line,r=1)
+        dv = self.modulo11(line, r=1)
         if dv == 0 or dv == 1:
             dv = 1
         else:
@@ -35,18 +37,9 @@ class BoletoReal( BoletoData ):
         return dv
 
     @property
-    def barcode(self):
-        num = "%3s%1s%1s%4s%10s%4s%7s%1s%13s" % ( \
-            self.codigo_banco, \
-            self.moeda,
-            'X',
-            self.fator_vencimento,
-            self.formata_valor(self.valor_documento,10),
-            self.agencia_cedente,
-            self.conta_cedente,
-            self.digitao_cobranca,
-            self.nosso_numero,
-        )
-        dv = self.calculate_dv_barcode(num.replace('X', '', 1))
-        num = num.replace('X', str(dv), 1)
-        return num
+    def campo_livre(self):
+        content = "%4s%7s%1s%13s" % (self.agencia_cedente,
+                                     self.conta_cedente,
+                                     self.digitao_cobranca,
+                                     self.nosso_numero)
+        return content
