@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 import unittest
 
+
 def suite():
     def my_import(name):
         # See http://docs.python.org/lib/built-in-funcs.html#l2h-6
@@ -16,17 +17,22 @@ def suite():
         return mod
 
     modules_to_test = [
+        'tests.test_banco_banrisul',
         'tests.test_banco_bradesco',
+        'tests.test_banco_do_brasil',
         'tests.test_banco_hsbc',
         'tests.test_banco_hsbc_com_registro',
         'tests.test_banco_caixa',
         'tests.test_banco_itau',
         'tests.test_banco_real',
+        'tests.test_pep8',
+        'tests.test_pyflakes',
     ]
     alltests = unittest.TestSuite()
     for module in map(my_import, modules_to_test):
         alltests.addTest(module.suite)
     return alltests
 
+
 if __name__ == '__main__':
     unittest.TextTestRunner(verbosity=2).run(suite())
