@@ -4,7 +4,10 @@ import datetime
 
 from pyboleto.bank.itau import BoletoItau
 
-class TestBancoItau(unittest.TestCase):
+from testutils import BoletoTestCase
+
+
+class TestBancoItau(BoletoTestCase):
     def setUp(self):
         d = BoletoItau()
         d.carteira = '109'
@@ -18,13 +21,16 @@ class TestBancoItau(unittest.TestCase):
         d.numero_documento = '456'
         self.dados = d
 
+    def test_render(self):
+        self.check_pdf_rendering('itau', self.dados)
+
     def test_linha_digitavel(self):
-        self.assertEqual(self.dados.linha_digitavel, 
+        self.assertEqual(self.dados.linha_digitavel,
             '34191.09008 00015.710296 30132.800001 9 43950000002980'
         )
-    
+
     def test_codigo_de_barras(self):
-        self.assertEqual(self.dados.barcode, 
+        self.assertEqual(self.dados.barcode,
             '34199439500000029801090000015710293013280000'
         )
 
@@ -44,4 +50,3 @@ suite = unittest.TestLoader().loadTestsFromTestCase(TestBancoItau)
 
 if __name__ == '__main__':
     unittest.main()
-
