@@ -4,7 +4,10 @@ import datetime
 
 from pyboleto.bank.real import BoletoReal
 
-class TestBancoBradesco(unittest.TestCase):
+from testutils import BoletoTestCase
+
+
+class TestBancoReal(BoletoTestCase):
     def setUp(self):
         d = BoletoReal()
         d.carteira = '06'
@@ -12,24 +15,26 @@ class TestBancoBradesco(unittest.TestCase):
         d.conta_cedente = '5705853'
         d.data_vencimento = datetime.date(2011, 2, 5)
         d.data_documento = datetime.date(2011, 1, 18)
-        d.data_processamento = datetime.date(201, 1, 18)
+        d.data_processamento = datetime.date(2011, 1, 18)
         d.valor_documento = 355.00
         d.nosso_numero = '123'
         d.numero_documento = '123'
         self.dados = d
 
+    def test_render(self):
+        self.check_pdf_rendering('real', self.dados)
+
     def test_linha_digitavel(self):
-        self.assertEqual(self.dados.linha_digitavel, 
+        self.assertEqual(self.dados.linha_digitavel,
             '35690.53154 70585.390001 00000.001230 8 48690000035500'
         )
-    
+
     def test_codigo_de_barras(self):
-        self.assertEqual(self.dados.barcode, 
+        self.assertEqual(self.dados.barcode,
             '35698486900000355000531570585390000000000123'
         )
 
-suite = unittest.TestLoader().loadTestsFromTestCase(TestBancoBradesco)
+suite = unittest.TestLoader().loadTestsFromTestCase(TestBancoReal)
 
 if __name__ == '__main__':
     unittest.main()
-
